insert into dws.test select * from dws.test_src limit 2000000 ---> 36s
insert /*+direct*/ into dws.test select * from dws.test_src limit 2000000 ---> 44s
per the document, I expect to some performance improvement by using the /*+direct*/ keyword, but apparently not in my test case, any suggestion?
Sign up
Already have an account? Login
Welcome to the Rocket Forum!
Please log in or register:
Employee Login | Registration Member Login | RegistrationEnter your E-mail address. We'll send you an e-mail with instructions to reset your password.